MTfit.inversion: Inversion object
=================================

The main :mod:`MTfit` inversion object is used to handle the forward model evaluation and process the results. The object initialisation and forward functions are documented here, although there are additional (private and special) functions that are documented in the source code.

.. autoclass:: MTfit.inversion.Inversion
    :members: forward